Enum caesar::cli::args::Commands

source ·
pub enum Commands {
    Send {
        relay: Option<String>,
        files: Vec<String>,
    },
    Receive {
        relay: Option<String>,
        name: String,
    },
    Serve {
        port: Option<i32>,
        listen_address: Option<String>,
    },
}

Variants



Send

Fields

relay: Option<String>

Address of the relay server. Accepted formats are: 127.0.0.1:8080, [::1]:8080, example.com

files: Vec<String>

Path to file(s)

Send files to the receiver or relay server



Receive

Fields

relay: Option<String>

Address of the relay server. Accepted formats are: 127.0.0.1:8080, [::1]:8080, example.com

name: String

Name of Transfer to download files

Receives Files from the sender with the matching password



Serve

Fields

port: Option<i32>

Port to run the relay server on

listen_address: Option<String>

The Listen address to run the relay server on

Start a relay server