pub struct Args {
pub command: Option<Commands>,
}Expand description
Struct representing the command line arguments parsed by clap.
It uses the clap library to define the command line arguments and their attributes. The version of the application is obtained from the cargo.toml file.
The command field is an optional subcommand. It is represented by the
Commands enum which defines the different subcommands that can be used.
Fields
command: Option<Commands>The subcommand to run.
It is an optional field. If it is not provided, the program will run without any specific subcommand.
Implementations